@@ -6,7 +6,7 @@ DIR=maven-shade-plugin-$VERSION
 TAG=$(echo "maven-shade-plugin-$VERSION" | sed -re's/~(alpha|beta)/-\1-/')
 
 svn export http://svn.apache.org/repos/asf/maven/plugins/tags/${TAG}/ $DIR
-GZIP=--best tar -c -z -f $TAR --exclude '*.jar' --exclude '*.class' $DIR
+GZIP=--best tar -c -z -f $TAR --exclude '*.class' $DIR
 rm -rf $DIR ../$TAG
 
 # move to directory 'tarballs'
